import React, { useEffect, useState, useRef } from 'react';
import { Card, CardContent, CardFooter } from "@/components/ui/card";
import { Star } from 'lucide-react';

const testimonials = [
  {
    id: 1,
    name: "Sarah Johnson",
    location: "United States",
    rating: 5,
    text: "Rajith was an exceptional guide who showed us the real Sri Lanka. His knowledge of history and culture made our trip so much more meaningful than if we'd traveled alone.",
    image: "https://images.unsplash.com/photo-1494790108377-be9c29b29330"
  },
  {
    id: 2,
    name: "Thomas Meyer",
    location: "Germany",
    rating: 5,
    text: "The wildlife safari was incredible! We saw elephants, leopards, and so many birds. Our guide knew exactly where to go and was passionate about conservation. Highly recommended!",
    image: "https://images.unsplash.com/photo-1507003211169-0a1dd7228f2d"
  },
  {
    id: 3,
    name: "Akiko Tanaka",
    location: "Japan",
    rating: 5,
    text: "Perfect organization from start to finish. The tea plantation tour was fascinating, and the hiking trails had breathtaking views. Excellent value for money!",
    image: "https://images.unsplash.com/photo-1554151228-14d9def656e4"
  },
  {
    id: 4,
    name: "Carlos Rodriguez",
    location: "Spain",
    rating: 5,
    text: "Our family tour was the highlight of our year! The children loved the elephant sanctuary and the beaches. Our guide was patient and made sure everyone enjoyed the experience.",
    image: "https://images.unsplash.com/photo-1500648767791-00dcc994a43e"
  },
  {
    id: 5,
    name: "Emma Wilson",
    location: "Australia",
    rating: 5,
    text: "The cultural immersion was fantastic. We stayed with a local family, learned traditional cooking, and even participated in a village festival. Unforgettable memories!",
    image: "https://images.unsplash.com/photo-1580489944761-15a19d654956"
  },
  {
    id: 6,
    name: "David Chang",
    location: "Canada",
    rating: 5,
    text: "The hiking tour exceeded all my expectations. The views from Adam's Peak at sunrise were breathtaking. Our guide was knowledgeable about local flora and fauna too.",
    image: "https://images.unsplash.com/photo-1599566150163-29194dcaad36"
  }
];

const Testimonials = () => {
  const [activeIndex, setActiveIndex] = useState(0);
  const [visibleItems, setVisibleItems] = useState(3);
  const [isTransitioning, setIsTransitioning] = useState(false);
  const testimonialRef = useRef(null);

  useEffect(() => {
    const handleResize = () => {
      if (window.innerWidth < 768) {
        setVisibleItems(1);
      } else if (window.innerWidth < 1024) {
        setVisibleItems(2);
      } else {
        setVisibleItems(3);
      }
    };

    handleResize();
    window.addEventListener('resize', handleResize);
    
    return () => {
      window.removeEventListener('resize', handleResize);
    };
  }, []);

  useEffect(() => {
    const interval = setInterval(() => {
      setIsTransitioning(true);
      setTimeout(() => {
        setActiveIndex((current) => 
          current + 1 >= testimonials.length ? 0 : current + 1
        );
        setIsTransitioning(false);
      }, 300);
    }, 4000);

    return () => clearInterval(interval);
  }, []);

  const getVisibleTestimonials = () => {
    const result = [];
    for (let i = 0; i < visibleItems; i++) {
      const index = (activeIndex + i) % testimonials.length;
      result.push(testimonials[index]);
    }
    return result;
  };

  const handleDotClick = (index) => {
    if (index !== activeIndex) {
      setIsTransitioning(true);
      setTimeout(() => {
        setActiveIndex(index);
        setIsTransitioning(false);
      }, 300);
    }
  };

  return (
    <section id="testimonials" className="py-20 bg-gradient-to-br from-green-50 to-green-100 relative overflow-hidden">
      <div className="absolute inset-0 bg-[url('https://images.unsplash.com/photo-1546975554-31053113e977')] bg-cover bg-fixed opacity-10"></div>
      <div className="container mx-auto px-4 relative z-10">
        <div className="text-center mb-12">
          <h2 className="text-3xl md:text-4xl font-display font-bold mb-4 text-gray-900">
            What Our Guests Say
          </h2>
          <p className="text-lg text-gray-600 max-w-2xl mx-auto">
            Don't just take our word for it - hear from travelers who have experienced the magic of Sri Lanka with us.
          </p>
        </div>
        
        <div className="relative overflow-hidden">
          <div 
            className={`transition-all duration-500 ease-in-out ${
              isTransitioning ? 'transform translate-x-full opacity-0' : 'transform translate-x-0 opacity-100'
            }`}
            ref={testimonialRef}
          >
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
              {getVisibleTestimonials().map((testimonial, index) => (
                <Card 
                  key={`${testimonial.id}-${activeIndex}-${index}`} 
                  className={`testimonial-card border-0 shadow-lg backdrop-blur-sm bg-white/80 transform transition-all duration-700 hover:scale-[1.02] ${
                    isTransitioning 
                      ? 'translate-y-4 opacity-0' 
                      : 'translate-y-0 opacity-100'
                  }`}
                  style={{ 
                    transitionDelay: `${index * 100}ms`,
                    animationDelay: `${index * 100}ms` 
                  }}
                >
                  <CardContent className="pt-6">
                    <div className="w-12 h-12 rounded-full overflow-hidden mx-auto mb-4 border-2 border-green-300 transition-transform duration-300 hover:scale-110">
                      <img 
                        src={testimonial.image} 
                        alt={testimonial.name} 
                        className="w-full h-full object-cover"
                      />
                    </div>
                    <div className="flex justify-center mb-4">
                      {[...Array(testimonial.rating)].map((_, i) => (
                        <Star 
                          key={i} 
                          size={18} 
                          className="text-yellow-400 fill-yellow-400 transform transition-transform duration-200 hover:scale-125"
                          style={{ animationDelay: `${(index * 100) + (i * 50)}ms` }}
                        />
                      ))}
                    </div>
                    <p className="text-gray-700 italic mb-6 text-center leading-relaxed">
                      "<span className="text-green-700 font-medium">{testimonial.text}</span>"
                    </p>
                  </CardContent>
                  <CardFooter className="flex items-center justify-center pt-2 border-t bg-gradient-to-r from-green-50 to-transparent">
                    <div className="text-center">
                      <h4 className="font-medium text-gray-900">{testimonial.name}</h4>
                      <p className="text-sm text-green-700">{testimonial.location}</p>
                    </div>
                  </CardFooter>
                </Card>
              ))}
            </div>
          </div>
        </div>
        
        <div className="flex justify-center mt-8">
          <div className="flex space-x-2">
            {testimonials.map((_, index) => (
              <button
                key={index}
                onClick={() => handleDotClick(index)}
                className={`transition-all duration-300 rounded-full ${
                  index === activeIndex 
                    ? "bg-green-600 w-6 h-2 shadow-lg" 
                    : "bg-gray-300 w-2 h-2 hover:bg-gray-400 hover:scale-125"
                }`}
                aria-label={`Go to testimonial ${index + 1}`}
              />
            ))}
          </div>
        </div>
      </div>

      <style jsx>{`
        @keyframes slideInFromRight {
          from {
            transform: translateX(100%);
            opacity: 0;
          }
          to {
            transform: translateX(0);
            opacity: 1;
          }
        }

        @keyframes slideInFromLeft {
          from {
            transform: translateX(-100%);
            opacity: 0;
          }
          to {
            transform: translateX(0);
            opacity: 1;
          }
        }

        @keyframes fadeInUp {
          from {
            transform: translateY(30px);
            opacity: 0;
          }
          to {
            transform: translateY(0);
            opacity: 1;
          }
        }

        .testimonial-card {
          animation: fadeInUp 0.6s ease-out forwards;
        }
      `}</style>
    </section>
  );
};

export default Testimonials;